@@ -39,7 +39,7 @@ require 5.013002;
 use strict;
 use warnings FATAL => 'all';
 
-my $url2pkg_pkgsrcdir = '/root/sda3/pkgsrc.2022Q2';
+my $url2pkg_pkgsrcdir = '/usr/pkgsrc';
 
 BEGIN {
 	use Exporter;
